@@ -423,6 +423,12 @@ class PipedCompressionReader(Closing):
     def seekable(self) -> bool:
         return self._file.seekable()
 
+    def tell(self) -> int:
+        return self._file.tell()
+
+    def seek(self, offset, whence=0) -> int:
+        return self._file.seek(offset, whence)
+
     def peek(self, n: int = None):
         if hasattr(self._file, "peek"):
             return self._file.peek(n)  # type: ignore
